========
Changes
========

0.04
-----

* Backwards incompatible version.
* Changes in the settings attributes. Now there is a single attribute
  for storing the configuration of all gateways and integrations. Check
  the docs for details.
* Changed the usage of the template tags. Refer the docs for details.
* Added a display_name to the integration object. Shouldn't affect users.

0.03
-----

* Added support for Stripe and Samurai gateways and integrations.

0.02
-----

* Added a setup.py and uploaded the package to pypi

0.01
-----

* Initial commit.
